# History

## 0.1.1

* Removal of unnecessary dependencies
* Separate `tabular` into `single_table` and `multi_table`
* Improve datasets stats collection.

## 0.1.0

* D3M Dataset parser
* Loaders by Data Modality
* Dataset Stats generator
* Dataset Configuration generator
* Metrics functions
* MongoDB connector
